@@ -21,6 +21,10 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// SBD includes.
+#include "sbdconf.h"
+#include "sbdconf.moc"
+
 // Qt includes.
 #include <QtCore/QFile>
 #include <QtCore/QFileInfo>
@@ -45,15 +49,11 @@
 #include "filterconf.h"
 #include "selectlanguagedlg.h"
 
-// SBD includes.
-#include "sbdconf.h"
-#include "sbdconf.moc"
-
 /**
 * Constructor
 */
-SbdConf::SbdConf( QWidget *parent, const QStringList &args) :
-    KttsFilterConf(parent)
+SbdConf::SbdConf( QWidget *parent, const QVariantList &args) :
+    KttsFilterConf(parent, args)
 {
     Q_UNUSED(args);
     // kDebug() << "SbdConf::SbdConf: Running";
@@ -149,7 +149,7 @@ void SbdConf::save(KConfig* c, const QString& configGroup){
     config.writeEntry("SentenceDelimiterRegExp", reLineEdit->text() );
     config.writeEntry("SentenceBoundary", sbLineEdit->text() );
     config.writeEntry("LanguageCodes", m_languageCodeList );
-    config.writeEntry("AppID", appIdLineEdit->text().replace(" ", "") );
+    config.writeEntry("AppID", appIdLineEdit->text().remove(' ') );
 }
 
 /**
@@ -203,8 +203,8 @@ void SbdConf::slotReButton_clicked()
 {
     // Show Regular Expression Editor dialog if it is installed.
     if ( !m_reEditorInstalled ) return;
-    QDialog *editorDialog =
-            KServiceTypeTrader::createInstanceFromQuery<QDialog>( "KRegExpEditor/KRegExpEditor" );
+    KDialog *editorDialog =
+            KServiceTypeTrader::createInstanceFromQuery<KDialog>( "KRegExpEditor/KRegExpEditor" );
     if ( editorDialog )
     {
         // kdeutils was installed, so the dialog was found.  Fetch the editor interface.
@@ -231,11 +231,16 @@ void SbdConf::slotLanguageBrowseButton_clicked()
         QStringList(m_languageCodeList),
         SelectLanguageDlg::MultipleSelect,
         SelectLanguageDlg::BlankAllowed);
-    int dlgResult = dlg->exec();
-    if (dlgResult == QDialog::Accepted)
+    if (dlg->exec())
+    {
         m_languageCodeList = dlg->selectedLanguageCodes();
+    }
+    else
+    {
+        delete dlg;
+	return;
+    }
     delete dlg;
-    if (dlgResult != QDialog::Accepted) return;
     QString language("");
     for ( int ndx=0; ndx < m_languageCodeList.count(); ++ndx)
     {
