@@ -1,7 +1,7 @@
 /***************************************************** vim:set ts=4 sw=4 sts=4:
   This file is the template for the processing plug ins.
   -------------------
-  Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández
+  Copyright : (C) 2002-2003 by José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
   Copyright : (C) 2004 by Gary Cramblitt <garycramblitt@comcast.net>
   -------------------
   Original author: José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
@@ -12,12 +12,13 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License.               *
+ *   the Free Software Foundation; version 2 of the License or             *
+ *   (at your option) version 3.                                           *
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _PLUGINPROC_H_
-#define _PLUGINPROC_H_
+#ifndef PLUGINPROC_H
+#define PLUGINPROC_H
 
 // Qt includes.
 #include <QtCore/QObject>
@@ -242,7 +243,7 @@ class KDE_EXPORT PlugInProc : public QObject{
         /**
         * Constructor.
         */
-        PlugInProc( QObject *parent = 0, const char *name = 0);
+        explicit PlugInProc( QObject *parent = 0, const char *name = 0);
 
         /**
         * Destructor.
@@ -464,4 +465,4 @@ class KDE_EXPORT PlugInProc : public QObject{
         void error(bool keepGoing, const QString &msg);
 };
 
-#endif // _PLUGINPROC_H_
+#endif // PLUGINPROC_H
