@@ -22,19 +22,22 @@
   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  ******************************************************************************/
 
+// TalkerCode includes.
+#include "talkercode.h"
+
+// Qt includes.
+#include <QtCore/QVector>
+
 // KDE includes.
 #include <kglobal.h>
 #include <klocale.h>
-#include <ktrader.h>
 #include <kdebug.h>
-
-// TalkerCode includes.
-#include "talkercode.h"
+#include <kservicetypetrader.h>
 
 /**
  * Constructor.
  */
-TalkerCode::TalkerCode(const QString &code/*=QString::null*/, bool normal /*=false*/)
+TalkerCode::TalkerCode(const QString &code/*=QString()*/, bool normal /*=false*/)
 {
     if (!code.isEmpty())
         parseTalkerCode(code);
@@ -46,6 +49,7 @@ TalkerCode::TalkerCode(const QString &code/*=QString::null*/, bool normal /*=fal
  */
 TalkerCode::TalkerCode(TalkerCode* talker, bool normal /*=false*/)
 {
+    m_id = talker->id();
     m_languageCode = talker->languageCode();
     m_countryCode = talker->countryCode();
     m_voice = talker->voice();
@@ -53,6 +57,7 @@ TalkerCode::TalkerCode(TalkerCode* talker, bool normal /*=false*/)
     m_volume = talker->volume();
     m_rate = talker->rate();
     m_plugInName = talker->plugInName();
+    m_desktopEntryName = talker->desktopEntryName();
     if (normal) normalize();
 }
 
@@ -64,6 +69,7 @@ TalkerCode::~TalkerCode() { }
 /**
  * Properties.
  */
+QString TalkerCode::id() const { return m_id; }
 QString TalkerCode::languageCode() const { return m_languageCode; }
 QString TalkerCode::countryCode() const { return m_countryCode; }
 QString TalkerCode::voice() const { return m_voice; }
@@ -71,7 +77,9 @@ QString TalkerCode::gender() const { return m_gender; }
 QString TalkerCode::volume() const { return m_volume; }
 QString TalkerCode::rate() const { return m_rate; }
 QString TalkerCode::plugInName() const { return m_plugInName; }
+QString TalkerCode::desktopEntryName() const { return m_desktopEntryName; }
 
+void TalkerCode::setId(const QString &id) { m_id = id; }
 void TalkerCode::setLanguageCode(const QString &languageCode) { m_languageCode = languageCode; }
 void TalkerCode::setCountryCode(const QString &countryCode) { m_countryCode = countryCode; }
 void TalkerCode::setVoice(const QString &voice) { m_voice = voice; }
@@ -79,6 +87,7 @@ void TalkerCode::setGender(const QString &gender) { m_gender = gender; }
 void TalkerCode::setVolume(const QString &volume) { m_volume = volume; }
 void TalkerCode::setRate(const QString &rate) { m_rate = rate; }
 void TalkerCode::setPlugInName(const QString plugInName) { m_plugInName = plugInName; }
+void TalkerCode::setDesktopEntryName(const QString &desktopEntryName) { m_desktopEntryName = desktopEntryName; }
 
 /**
  * Sets the language code and country code (if given).
@@ -94,7 +103,7 @@ void TalkerCode::setFullLanguageCode(const QString &fullLanguageCode)
 QString TalkerCode::fullLanguageCode() const
 {
     if (!m_countryCode.isEmpty())
-        return m_languageCode + "_" + m_countryCode;
+        return m_languageCode + '_' + m_countryCode;
     else
         return m_languageCode;
 }
@@ -102,11 +111,16 @@ QString TalkerCode::fullLanguageCode() const
 /**
  * The Talker Code returned in XML format.
  */
+void TalkerCode::setTalkerCode(const QString& code)
+{
+    parseTalkerCode(code);
+}
+
 QString TalkerCode::getTalkerCode() const
 {
     QString code;
     QString languageCode = m_languageCode;
-    if (!m_countryCode.isEmpty()) languageCode += "_" + m_countryCode;
+    if (!m_countryCode.isEmpty()) languageCode += '_' + m_countryCode;
     if (!languageCode.isEmpty()) code = "lang=\"" + languageCode + "\" ";
     if (!m_voice.isEmpty()) code += "name=\"" + m_voice + "\" ";
     if (!m_gender.isEmpty()) code += "gender=\"" + m_gender + "\" ";
@@ -131,13 +145,13 @@ QString TalkerCode::getTranslatedDescription() const
     // TODO: The PlugInName is always English.  Need a way to convert this to a translated
     // name (possibly via DesktopEntryNameToName, but to do that, we need the desktopEntryName
     // from the config file).
-    if (!m_plugInName.isEmpty()) code += " " + stripPrefer(m_plugInName, prefer);
-    if (!m_voice.isEmpty()) code += " " + stripPrefer(m_voice, prefer);
-    if (!m_gender.isEmpty()) code += " " + translatedGender(stripPrefer(m_gender, prefer));
-    if (!m_volume.isEmpty()) code += " " + translatedVolume(stripPrefer(m_volume, prefer));
-    if (!m_rate.isEmpty()) code += " " + translatedRate(stripPrefer(m_rate, prefer));
-    code = code.stripWhiteSpace();
-    if (code.isEmpty()) code = i18n("default");
+    if (!m_plugInName.isEmpty()) code += ' ' + stripPrefer(m_plugInName, prefer);
+    if (!m_voice.isEmpty()) code += ' ' + stripPrefer(m_voice, prefer);
+    if (!m_gender.isEmpty()) code += ' ' + translatedGender(stripPrefer(m_gender, prefer));
+    if (!m_volume.isEmpty()) code += ' ' + translatedVolume(stripPrefer(m_volume, prefer));
+    if (!m_rate.isEmpty()) code += ' ' + translatedRate(stripPrefer(m_rate, prefer));
+    code = code.trimmed();
+    if (code.isEmpty()) code = i18nc("Default language code", "default");
     return code;
 }
 
@@ -181,8 +195,9 @@ void TalkerCode::normalize()
 {
     QString language = lang;
     if (language.left(1) == "*") language = language.mid(1);
+    QString modifier;
     QString charSet;
-    KGlobal::locale()->splitLocale(language, languageCode, countryCode, charSet);
+    KGlobal::locale()->splitLocale(language, languageCode, countryCode, modifier, charSet);
 }
 
 /**
@@ -210,25 +225,25 @@ void TalkerCode::normalize()
  */
 /*static*/ QString TalkerCode::languageCodeToLanguage(const QString &languageCode)
 {
-    QString twoAlpha;
+    QString langAlpha;
     QString countryCode;
     QString language;
     if (languageCode == "other")
-        language = i18n("Other");
+        language = i18nc("Other language", "Other");
     else
     {
-        splitFullLanguageCode(languageCode, twoAlpha, countryCode);
-        language = KGlobal::locale()->twoAlphaToLanguageName(twoAlpha);
+        splitFullLanguageCode(languageCode, langAlpha, countryCode);
+        language = KGlobal::locale()->languageCodeToName(langAlpha);
     }
     if (!countryCode.isEmpty())
     {
-        QString countryName = KGlobal::locale()->twoAlphaToCountryName(countryCode);
+        QString countryName = KGlobal::locale()->countryCodeToName(countryCode);
         // Some abbreviations to save screen space.
-        if (countryName == i18n("full country name", "United States of America"))
-            countryName = i18n("abbreviated country name", "USA");
-        if (countryName == i18n("full country name", "United Kingdom"))
-            countryName = i18n("abbreviated country name", "UK");
-        language += " (" + countryName + ")";
+        if (countryName == i18nc("full country name", "United States of America"))
+            countryName = i18nc("abbreviated country name", "USA");
+        if (countryName == i18nc("full country name", "United Kingdom"))
+            countryName = i18nc("abbreviated country name", "UK");
+        language += " (" + countryName + ')';
     }
     return language;
 }
@@ -239,60 +254,60 @@ void TalkerCode::normalize()
 /*static*/ QString TalkerCode::translatedGender(const QString &gender)
 {
     if (gender == "male")
-        return i18n("male");
+        return i18nc("Male gender", "male");
     else if (gender == "female")
-        return i18n("female");
+        return i18nc("Female gender", "female");
     else if (gender == "neutral")
-        return i18n("neutral gender", "neutral");
+        return i18nc("neutral gender", "neutral");
     else return gender;
 }
 /*static*/ QString TalkerCode::untranslatedGender(const QString &gender)
 {
-    if (gender == i18n("male"))
+    if (gender == i18nc("Male gender", "male"))
         return "male";
-    else if (gender == i18n("female"))
+    else if (gender == i18nc("Female gender", "female"))
         return "female";
-    else if (gender == i18n("neutral gender", "neutral"))
+    else if (gender == i18nc("neutral gender", "neutral"))
         return "neutral";
     else return gender;
 }
 /*static*/ QString TalkerCode::translatedVolume(const QString &volume)
 {
     if (volume == "medium")
-        return i18n("medium sound", "medium");
+        return i18nc("medium sound", "medium");
     else if (volume == "loud")
-        return i18n("loud sound", "loud");
+        return i18nc("loud sound", "loud");
     else if (volume == "soft")
-        return i18n("soft sound", "soft");
+        return i18nc("soft sound", "soft");
     else return volume;
 }
 /*static*/ QString TalkerCode::untranslatedVolume(const QString &volume)
 {
-    if (volume == i18n("medium sound", "medium"))
+    if (volume == i18nc("medium sound", "medium"))
         return "medium";
-    else if (volume == i18n("loud sound", "loud"))
+    else if (volume == i18nc("loud sound", "loud"))
         return "loud";
-    else if (volume == i18n("soft sound", "soft"))
+    else if (volume == i18nc("soft sound", "soft"))
         return "soft";
     else return volume;
 }
 /*static*/ QString TalkerCode::translatedRate(const QString &rate)
 {
     if (rate == "medium")
-        return i18n("medium speed", "medium");
+        return i18nc("medium speed", "medium");
     else if (rate == "fast")
-        return i18n("fast speed", "fast");
+        return i18nc("fast speed", "fast");
     else if (rate == "slow")
-        return i18n("slow speed", "slow");
+        return i18nc("slow speed", "slow");
     else return rate;
 }
 /*static*/ QString TalkerCode::untranslatedRate(const QString &rate)
 {
-    if (rate == i18n("medium speed", "medium"))
+    if (rate == i18nc("medium speed", "medium"))
         return "medium";
-    else if (rate == i18n("fast speed", "fast"))
+    else if (rate == i18nc("fast speed", "fast"))
         return "fast";
-    else if (rate == i18n("slow speed", "slow"))
+    else if (rate == i18nc("slow speed", "slow"))
         return "slow";
     else return rate;
 }
@@ -315,7 +330,7 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
     QString countryCode;
     splitFullLanguageCode(fullLanguageCode, languageCode, countryCode);
     m_languageCode = languageCode;
-    if (fullLanguageCode.left(1) == "*") countryCode = "*" + countryCode;
+    if (fullLanguageCode.left(1) == "*") countryCode = '*' + countryCode;
     m_countryCode = countryCode;
     m_voice = talkerCode.section("name=", 1, 1);
     m_voice = m_voice.section('"', 1, 1);
@@ -343,7 +358,7 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
     const QString& talker,
     bool assumeDefaultLang)
 {
-    // kdDebug() << "TalkerCode::findClosestMatchingTalker: matching on talker code " << talker << endl;
+    // kDebug() << "TalkerCode::findClosestMatchingTalker: matching on talker code " << talker;
     // If nothing to match on, winner is top in the list.
     if (talker.isEmpty()) return 0;
     // Parse the given talker.
@@ -356,15 +371,15 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
     }
     // The talker that matches on the most priority attributes wins.
     int talkersCount = int(talkers.count());
-    QMemArray<int> priorityMatch(talkersCount);
+    QVector<int> priorityMatch(talkersCount);
     for (int ndx = 0; ndx < talkersCount; ++ndx)
     {
         priorityMatch[ndx] = 0;
-        // kdDebug() << "Comparing language code " << parsedTalkerCode.languageCode() << " to " << m_loadedPlugIns[ndx].parsedTalkerCode.languageCode() << endl;
+        // kDebug() << "Comparing language code " << parsedTalkerCode.languageCode() << " to " << m_loadedPlugIns[ndx].parsedTalkerCode.languageCode();
         if (parsedTalkerCode.languageCode() == talkers[ndx].languageCode())
         {
             ++priorityMatch[ndx];
-            // kdDebug() << "TalkerCode::findClosestMatchingTalker: Match on language " << parsedTalkerCode.languageCode() << endl;
+            // kDebug() << "TalkerCode::findClosestMatchingTalker: Match on language " << parsedTalkerCode.languageCode();
         }
         if (parsedTalkerCode.countryCode().left(1) == "*")
             if (parsedTalkerCode.countryCode().mid(1) ==
@@ -404,7 +419,7 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
             winner = ndx;
         }
     }
-    // kdDebug() << "Priority phase: winnerCount = " << winnerCount 
+    // kDebug() << "Priority phase: winnerCount = " << winnerCount 
     //     << " winner = " << winner
     //     << " maxPriority = " << maxPriority << endl;
     // If a tie, the one that matches on the most priority and preferred attributes wins.
@@ -412,7 +427,7 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
     // (first configured) will be chosen.
     if (winnerCount > 1)
     {
-        QMemArray<int> preferredMatch(talkersCount);
+        QVector<int> preferredMatch(talkersCount);
         for (int ndx = 0; ndx < talkersCount; ++ndx)
         {
             preferredMatch[ndx] = 0;
@@ -461,13 +476,13 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
                 }
             }
         }
-        // kdDebug() << "Preferred phase: winnerCount = " << winnerCount 
+        // kDebug() << "Preferred phase: winnerCount = " << winnerCount 
         //     << " winner = " << winner
         //     << " maxPreferred = " << maxPreferred << endl;
     }
     // If no winner found, use the first talker.
     if (winner < 0) winner = 0;
-    // kdDebug() << "TalkerCode::findClosestMatchingTalker: returning winner = " << winner << endl;
+    // kDebug() << "TalkerCode::findClosestMatchingTalker: returning winner = " << winner;
     return winner;
 }
 
@@ -487,15 +502,15 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
 * Uses KTrader to convert a translated Synth Plugin Name to DesktopEntryName.
 * @param name                   The translated plugin name.  From Name= line in .desktop file.
 * @return                       DesktopEntryName.  The name of the .desktop file (less .desktop).
-*                               QString::null if not found.
+*                               QString() if not found.
 */
 /*static*/ QString TalkerCode::TalkerNameToDesktopEntryName(const QString& name)
 {
-    if (name.isEmpty()) return QString::null;
-    KTrader::OfferList offers = KTrader::self()->query("KTTSD/SynthPlugin");
-    for (uint ndx = 0; ndx < offers.count(); ++ndx)
+    if (name.isEmpty()) return QString();
+    KService::List  offers = KServiceTypeTrader::self()->query("KTTSD/SynthPlugin");
+    for (int ndx = 0; ndx < offers.count(); ++ndx)
         if (offers[ndx]->name() == name) return offers[ndx]->desktopEntryName();
-    return QString::null;
+    return QString();
 }
 
 /**
@@ -505,13 +520,13 @@ void TalkerCode::parseTalkerCode(const QString &talkerCode)
 */
 /*static*/ QString TalkerCode::TalkerDesktopEntryNameToName(const QString& desktopEntryName)
 {
-    if (desktopEntryName.isEmpty()) return QString::null;
-    KTrader::OfferList offers = KTrader::self()->query("KTTSD/SynthPlugin",
+    if (desktopEntryName.isEmpty()) return QString();
+	KService::List offers = KServiceTypeTrader::self()->query("KTTSD/SynthPlugin",
     QString("DesktopEntryName == '%1'").arg(desktopEntryName));
 
     if (offers.count() == 1)
         return offers[0]->name();
     else
-        return QString::null;
+        return QString();
 }
 
